@@ -79,7 +79,7 @@
 
                 matchStringHtml += '</paper-item-body>';
 
-                matchStringHtml += '<paper-icon-button icon="delete" class="btnDeleteMatchEntry" data-index="' + i + '" data-matchindex="' + matchStringIndex + '" title="' + Globalize.translate('ButtonDelete') + '"></paper-icon-button>';
+                matchStringHtml += '<button type="button" is="paper-icon-button-light" class="btnDeleteMatchEntry" data-index="' + i + '" data-matchindex="' + matchStringIndex + '" title="' + Globalize.translate('ButtonDelete') + '"><iron-icon icon="delete"></iron-icon></button>';
 
                 matchStringHtml += '</paper-icon-item>';
                 matchStringIndex++;
@@ -105,6 +105,22 @@
         });
     }
 
+    function getTabs() {
+        return [
+        {
+            href: 'autoorganizelog.html',
+            name: Globalize.translate('TabActivityLog')
+        },
+         {
+             href: 'autoorganizetv.html',
+             name: Globalize.translate('TabTV')
+         },
+         {
+             href: 'autoorganizesmart.html',
+             name: Globalize.translate('TabSmartMatches')
+         }];
+    }
+
     $(document).on('pageinit', "#libraryFileOrganizerSmartMatchPage", function () {
 
         var page = this;
@@ -134,6 +150,8 @@
 
         var page = this;
 
+        LibraryMenu.setTabs('autoorganize', 2, getTabs);
+
         Dashboard.showLoadingMsg();
 
         reloadList(page);
