@@ -1,4 +1,4 @@
-﻿(function (window) {
+﻿define(['appStorage'], function (appStorage) {
 
     var currentDisplayInfo;
     function mirrorItem(info) {
@@ -38,7 +38,7 @@
                 NowPlayingItem: state.NowPlayingItem
             };
 
-            info = $.extend(info, state.PlayState);
+            info = Object.assign(info, state.PlayState);
 
             ApiClient.reportPlaybackStart(info);
 
@@ -88,7 +88,7 @@
                 return {
                     name: name,
                     id: t.id,
-                    ironIcon: 'tablet-android'
+                    ironIcon: playerInfo.id == t.id ? 'check' : null
                 };
 
             });
@@ -119,19 +119,25 @@
 
     function showActivePlayerMenu(playerInfo) {
 
-        require(['paper-checkbox', 'fade-in-animation', 'fade-out-animation', 'paper-dialog'], function () {
-            showActivePlayerMenuInternal(playerInfo);
+        require(['dialogHelper', 'paper-checkbox', ], function (dialogHelper) {
+            showActivePlayerMenuInternal(dialogHelper, playerInfo);
         });
     }
 
-    function showActivePlayerMenuInternal(playerInfo) {
+    function showActivePlayerMenuInternal(dialogHelper, playerInfo) {
 
-        var id = 'dlg' + new Date().getTime();
         var html = '';
 
-        var style = "";
+        var dialogOptions = {
+            removeOnClose: true
+        };
 
-        html += '<paper-dialog id="' + id + '" entry-animation="fade-in-animation" exit-animation="fade-out-animation" with-backdrop style="' + style + '">';
+        dialogOptions.modal = false;
+        dialogOptions.entryAnimationDuration = 160;
+        dialogOptions.exitAnimationDuration = 160;
+        dialogOptions.autoFocus = false;
+
+        var dlg = dialogHelper.createDialog(dialogOptions);
 
         html += '<h2>';
         html += (playerInfo.deviceName || playerInfo.name);
@@ -153,31 +159,47 @@
 
         // On small layouts papepr dialog doesn't respond very well. this button isn't that important here anyway.
         if (screen.availWidth >= 600) {
-            html += '<paper-button onclick="Dashboard.navigate(\'nowplaying.html\');" dialog-dismiss>' + Globalize.translate('ButtonRemoteControl') + '</paper-button>';
+            html += '<paper-button class="btnRemoteControl">' + Globalize.translate('ButtonRemoteControl') + '</paper-button>';
         }
 
-        html += '<paper-button dialog-dismiss onclick="MediaController.disconnectFromPlayer();">' + Globalize.translate('ButtonDisconnect') + '</paper-button>';
-        html += '<paper-button dialog-dismiss>' + Globalize.translate('ButtonCancel') + '</paper-button>';
+        html += '<paper-button class="btnDisconnect">' + Globalize.translate('ButtonDisconnect') + '</paper-button>';
+        html += '<paper-button class="btnCancel">' + Globalize.translate('ButtonCancel') + '</paper-button>';
         html += '</div>';
 
-        html += '</paper-dialog>';
+        dlg.innerHTML = html;
 
-        $(document.body).append(html);
+        document.body.appendChild(dlg);
 
-        setTimeout(function () {
+        var chkMirror = dlg.querySelector('.chkMirror');
 
-            var dlg = document.getElementById(id);
+        if (chkMirror) {
+            chkMirror.addEventListener('change', onMirrorChange);
+        }
 
-            $('.chkMirror', dlg).on('change', onMirrorChange);
+        var destination = '';
 
-            dlg.open();
-
-            // Has to be assigned a z-index after the call to .open() 
-            $(dlg).on('iron-overlay-closed', function () {
-                $(this).remove();
+        var btnRemoteControl = dlg.querySelector('.btnRemoteControl');
+        if (btnRemoteControl) {
+            btnRemoteControl.addEventListener('click', function () {
+                destination = 'nowplaying.html';
+                dialogHelper.close(dlg);
             });
+        }
 
-        }, 100);
+        dlg.querySelector('.btnDisconnect').addEventListener('click', function () {
+            MediaController.disconnectFromPlayer();
+            dialogHelper.close(dlg);
+        });
+
+        dlg.querySelector('.btnCancel').addEventListener('click', function () {
+            dialogHelper.close(dlg);
+        });
+
+        dialogHelper.open(dlg).then(function () {
+            if (destination) {
+                Dashboard.navigate(destination);
+            }
+        });
     }
 
     function onMirrorChange() {
@@ -802,15 +824,13 @@
 
         self.showPlaybackInfoErrorMessage = function (errorCode) {
 
-            // This timeout is messy, but if jqm is in the act of hiding a popup, it will not show a new one
-            // If we're coming from the popup play menu, this will be a problem
-
-            setTimeout(function () {
-                Dashboard.alert({
-                    message: Globalize.translate('MessagePlaybackError' + errorCode),
-                    title: Globalize.translate('HeaderPlaybackError')
+            require(['alert'], function (alert) {
+                alert({
+                    title: Globalize.translate('HeaderPlaybackError'),
+                    text: Globalize.translate('MessagePlaybackError' + errorCode),
+                    type: 'error'
                 });
-            }, 300);
+            });
 
         };
 
@@ -1047,7 +1067,9 @@
 
     document.addEventListener('headercreated', function () {
 
-        $('.btnCast').off('click', onCastButtonClicked).on('click', onCastButtonClicked);
+        var btnCast = document.querySelector('.viewMenuBar .btnCast');
+        btnCast.removeEventListener('click', onCastButtonClicked);
+        btnCast.addEventListener('click', onCastButtonClicked);
     });
 
     pageClassOn('pagebeforeshow', "page", function () {
@@ -1063,4 +1085,4 @@
         mirrorIfEnabled(info);
     });
 
-})(this);
\ No newline at end of file
+});
\ No newline at end of file
