@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'paper-icon-button-light'], function ($) {
 
     function connectToServer(page, server) {
 
@@ -26,9 +26,12 @@
                     break;
                 case MediaBrowser.ConnectionState.ServerUpdateNeeded:
                     {
-                        Dashboard.alert({
-                            message: Globalize.translate('ServerUpdateNeeded', '<a href="https://emby.media">https://emby.media</a>')
-                        });
+                        Dashboard.alert(alert({
+
+                            text: Globalize.translate('core#ServerUpdateNeeded', 'https://emby.media'),
+                            html: Globalize.translate('core#ServerUpdateNeeded', '<a href="https://emby.media">https://emby.media</a>')
+
+                        }));
                     }
                     break;
                 default:
@@ -70,7 +73,7 @@
         html += '</paper-item-body>';
 
         if (server.Id) {
-            html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnServerMenu"></paper-icon-button>';
+            html += '<button is="paper-icon-button-light" class="btnServerMenu"><iron-icon icon="' + AppInfo.moreIcon + '"></iron-icon></button>';
         }
 
         html += '</paper-icon-item>';
@@ -272,7 +275,7 @@
 
         html += '</paper-item-body>';
 
-        html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnInviteMenu"></paper-icon-button>';
+        html += '<button is="paper-icon-button-light" class="btnInviteMenu"><iron-icon icon="' + AppInfo.moreIcon + '"></iron-icon></button>';
 
         html += '</paper-icon-item>';
 
