@@ -1,4 +1,4 @@
-﻿define(['appStorage', 'jQuery'], function (appStorage, $) {
+﻿define(['appStorage', 'jQuery', 'paper-button'], function (appStorage, $) {
 
     $.fn.taskButton = function (options) {
 
@@ -59,10 +59,10 @@
                 var lastResult = task.LastExecutionResult ? task.LastExecutionResult.Status : '';
 
                 if (lastResult == "Failed") {
-                    options.lastResultElem.html('<span style="color:#FF0000;">' + Globalize.translate('LabelFailed') + '</span>');
+                    options.lastResultElem.html('<span style="color:#FF0000;">(' + Globalize.translate('LabelFailed') + ')</span>');
                 }
                 else if (lastResult == "Cancelled") {
-                    options.lastResultElem.html('<span style="color:#0026FF;">' + Globalize.translate('LabelCancelled') + '</span>');
+                    options.lastResultElem.html('<span style="color:#0026FF;">(' + Globalize.translate('LabelCancelled') + ')</span>');
                 }
                 else if (lastResult == "Aborted") {
                     options.lastResultElem.html('<span style="color:#FF0000;">' + Globalize.translate('LabelAbortedByServerShutdown') + '</span>');
@@ -85,7 +85,7 @@
             var id = button.getAttribute('data-taskid');
 
             var key = 'scheduledTaskButton' + options.taskKey;
-            var expectedValue = new Date().getMonth() + '5';
+            var expectedValue = new Date().getMonth() + '6';
 
             if (appStorage.getItem(key) == expectedValue) {
                 onScheduledTaskMessageConfirmed(button, id);
@@ -99,7 +99,13 @@
 
                 require(['confirm'], function (confirm) {
 
-                    confirm(msg, Globalize.translate('HeaderConfirmation')).then(function () {
+                    confirm({
+
+                        title: Globalize.translate('HeaderConfirmation'),
+                        html: msg,
+                        text: Globalize.translate('ConfirmMessageScheduledTaskButton') + "\n\n" + Globalize.translate('ButtonScheduledTasks')
+
+                    }).then(function () {
                         appStorage.setItem(key, expectedValue);
                         onScheduledTaskMessageConfirmed(button, id);
                     });
