@@ -1,19 +1,21 @@
-﻿(function (document, window, $) {
+﻿define(['jQuery', 'paper-icon-button-light'], function ($) {
 
     function deleteUser(page, id) {
 
         var msg = Globalize.translate('DeleteUserConfirmation');
 
-        Dashboard.confirm(msg, Globalize.translate('DeleteUser'), function (result) {
+        require(['confirm'], function (confirm) {
+
+            confirm(msg, Globalize.translate('DeleteUser')).then(function () {
 
-            if (result) {
                 Dashboard.showLoadingMsg();
 
                 ApiClient.deleteUser(id).then(function () {
 
                     loadData(page);
                 });
-            }
+            });
+
         });
     }
 
@@ -134,7 +136,7 @@
         html += '<div class="cardFooter">';
 
         html += '<div class="cardText" style="text-align:right; float:right;padding:0;">';
-        html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnUserMenu"></paper-icon-button>';
+        html += '<button type="button" is="paper-icon-button-light" class="btnUserMenu"><iron-icon icon="' + AppInfo.moreIcon + '"></iron-icon></button>';
         html += "</div>";
 
         html += '<div class="cardText" style="padding-top:10px;padding-bottom:10px;">';
@@ -170,7 +172,7 @@
 
         var html = getUserSectionHtml(users, addConnectIndicator);
 
-        elem.html(html).trigger('create');
+        elem.html(html);
 
         $('.btnUserMenu', elem).on('click', function () {
             showUserMenu(this);
@@ -253,7 +255,7 @@
         html += '<div class="cardFooter">';
 
         html += '<div class="cardText" style="text-align:right; float:right;padding:0;">';
-        html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnUserMenu"></paper-icon-button>';
+        html += '<button type="button" is="paper-icon-button-light" class="btnUserMenu"><iron-icon icon="' + AppInfo.moreIcon + '"></iron-icon></button>';
         html += "</div>";
 
         html += '<div class="cardText" style="padding-top:10px;padding-bottom:10px;">';
@@ -282,7 +284,7 @@
 
         var html = users.map(getPendingUserHtml).join('');
 
-        var elem = $('.pending', page).html(html).trigger('create');
+        var elem = $('.pending', page).html(html);
 
         $('.btnUserMenu', elem).on('click', function () {
             showPendingUserMenu(this);
@@ -338,9 +340,11 @@
                 msg += '<a href="useredit.html?userId=' + user.Id + '">' + Globalize.translate('ButtonLinkMyEmbyAccount') + '</a>';
                 msg += '<br/>';
 
-                Dashboard.alert({
-                    message: msg,
-                    title: Globalize.translate('HeaderInviteGuest')
+                require(['alert'], function (alert) {
+                    alert({
+                        title: Globalize.translate('HeaderInviteGuest'),
+                        text: msg
+                    });
                 });
                 return;
             }
@@ -375,4 +379,4 @@
         loadData(page);
     });
 
-})(document, window, jQuery);
\ No newline at end of file
+});
\ No newline at end of file
